@@ -1,43 +1,46 @@
 module java.base {
-    exports java.sql;
-    exports java.lang.constant;
-    exports java.util;
-    exports javax.lang.model.util;
-    exports java.security.acl;
     exports java.beans;
-    exports java.util.stream;
-    exports javax.lang.model;
+    exports java.io;
+    exports java.lang;
     exports java.lang.annotation;
+    exports java.lang.constant;
+    exports java.lang.foreign;
+    exports java.lang.invoke;
+    exports java.lang.module;
+    exports java.lang.ref;
+    exports java.lang.reflect;
+    exports java.lang.runtime;
+    exports java.math;
+    exports java.net;
     exports java.nio;
     exports java.nio.channels;
-    exports javax.lang.model.type;
-    exports java.security.cert;
-    exports java.util.zip;
-    exports java.nio.file;
-    exports java.nio.charset;
-    exports java.security.spec;
-    exports java.nio.file.spi;
-    exports javax.annotation.processing;
-    exports java.lang.ref;
-    exports java.net;
-    exports java.util.regex;
-    exports java.security.interfaces;
-    exports java.lang.invoke;
-    exports java.math;
-    exports javax.lang.model.element;
-    exports java.lang.reflect;
-    exports java.security;
-    exports java.util.concurrent;
-    exports javax.tools;
-    exports java.lang.module;
-    exports java.lang;
-    exports java.text;
-    exports java.io;
     exports java.nio.channels.spi;
-    exports java.util.jar;
-    exports java.util.function;
+    exports java.nio.charset;
     exports java.nio.charset.spi;
+    exports java.nio.file;
     exports java.nio.file.attribute;
+    exports java.nio.file.spi;
+    exports java.security;
+    exports java.security.cert;
+    exports java.security.interfaces;
+    exports java.security.spec;
+    exports java.sql;
+    exports java.text;
+    exports java.util;
+    exports java.util.concurrent;
+    exports java.util.concurrent.atomic;
+    exports java.util.function;
+    exports java.util.jar;
+    exports java.util.random;
+    exports java.util.regex;
+    exports java.util.stream;
+    exports java.util.zip;
+    exports javax.annotation.processing;
+    exports javax.lang.model;
+    exports javax.lang.model.element;
+    exports javax.lang.model.type;
+    exports javax.lang.model.util;
+    exports javax.tools;
 
 }
 
